@@ -12,7 +12,7 @@ import numpy as np
 import zstandard as zstd
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 
 @contextlib.contextmanager
@@ -32,7 +32,7 @@ def zstd_open_read(path, *args, **kwargs):
 
 
 class HashSink:
-    def __init__(h=hashlib.sha1()):
+    def __init__(self, h=hashlib.sha1()):
         self._h = h
 
     def write(self, b: bytes):
